@@ -1,6 +1,13 @@
 package Mail::SimpleList::Alias;
 
 use strict;
+
+use Mail::Action::Address;
+use Class::Roles
+	does => 'address_expires',
+	does => 'address_named',
+	does => 'address_described';
+
 use Mail::Address;
 
 use vars qw( $VERSION );
@@ -86,37 +93,6 @@ sub is_true
 
 }
 
-sub expires
-{
-	my $self = shift;
-	$self->{expires} = $self->process_time( shift ) + time() if @_;
-	return $self->{expires};
-}
-
-sub process_time
-{
-	my ($self, $time) = @_;
-	return $time unless $time =~ tr/0-9//c;
-
-	my %times = (
-		m =>                60,
-		h =>           60 * 60,
-		d =>      24 * 60 * 60,
-		w =>  7 * 24 * 60 * 60,
-		M => 30 * 24 * 60 * 60,
-	);
-
-	my $units    = join('', keys %times);
-	my $seconds; 
-
-	while ( $time =~ s/(\d+)([$units])// )
-	{
-		$seconds += $1 * $times{ $2 };
-	}
-
-	return $seconds;
-}
-
 sub auto_add
 {
 	my $self = shift;
@@ -124,20 +100,6 @@ sub auto_add
 	return $self->{auto_add};
 }
 
-sub description
-{
-	my $self             = shift;
-	$self->{description} = shift if @_;
-	return $self->{description};
-}
-
-sub name
-{
-	my $self       = shift;
-	($self->{name} = shift) =~ tr/-A-Za-z0-9_//cd if @_;
-	return $self->{name};
-}
-
 sub attributes
 {
 	+{ map { $_ => 1 } qw( owner closed expires auto_add description name ) }
@@ -251,6 +213,10 @@ None known.
 
 No plans.  It's pretty nice as it is.
 
+=head1 SEE ALSO
+
+L<Mail::Action::Address>, the parent class.
+
 =head1 COPYRIGHT
 
 Copyright (c) 2003, chromatic.  All rights reserved.  This module is
